# pkgmt

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


A toolkit for managing Python packages 📦🐍

`pkgmt` allows you to create new Python packages that follow best practices: README, CHANGELOG, a command to bootstrap the environment, CI with GitHub Actions, and more!

## Installation

```sh
pip install pkgmt
```

## Support

For support, feature requests, and product updates: [join our community](https://ploomber.io/community) or follow us on [Twitter](https://twitter.com/ploomber)/[LinkedIn](https://www.linkedin.com/company/ploomber/).

## Features

## Create a new package

```sh
pkgmt new mynewpackage
```

## Test your README

Test your README to ensure it runs!

```
pkgmt test-md --file README.md
```
